@@ -9,9 +9,11 @@ import logging
 import sys
 import time
 import hashlib
+import traceback
 from dataclasses import dataclass
-from os.path import isdir, isfile, exists, join, basename
-from typing import Callable, Dict, Optional, Union, Iterable, List
+from functools import lru_cache
+from os.path import isdir, isfile, join, basename
+from typing import Callable, Dict, Optional, Union, Iterable, List, cast
 import yaml
 import pandas as pd
 import hail as hl
@@ -19,6 +21,7 @@ import click
 from google.cloud import storage
 from joint_calling import _version, get_package_path
 from joint_calling import __name__ as package_name
+from cpg_utils import Path, to_path
 
 logger = logging.getLogger(__file__)
 logging.basicConfig(format='%(levelname)s (%(name)s %(lineno)s): %(message)s')
@@ -71,12 +74,7 @@ def init_hail(name: str, local_tmp_dir: str = None):
     """
     if not local_tmp_dir:
         local_tmp_dir = tempfile.mkdtemp()
-
-    timestamp = time.strftime('%Y%m%d-%H%M')
-    hl_log = os.path.join(
-        safe_mkdir(os.path.join(local_tmp_dir, 'log')), f'{name}-{timestamp}.log'
-    )
-    hl.init(default_reference=DEFAULT_REF, log=hl_log)
+    hl.init(default_reference=DEFAULT_REF)
     logger.info(f'Running joint-calling version {_version.__version__}')
     return local_tmp_dir
 
@@ -193,34 +191,56 @@ class ColumnInFile:
         return data_by_sample
 
 
-def file_exists(path: str) -> bool:
+@lru_cache
+def file_exists(path: Union[Path, str, None], verbose: bool = True) -> bool:
+    """
+    Caching version of the existence check. 
+    The python code runtime happens entirely during the pipeline submittion, 
+    without waiting for it to finish, so there is no expectation that object 
+    existence status would change during the runtime. This, this function uses
+    `@lru_cache` to make sure that object existence is checked only once.
+    """
+    return exists_not_cached(path, verbose)
+
+
+def exists_not_cached(path: Union[Path, str, None], verbose: bool = True) -> bool:
     """
     Check if the object exists, where the object can be:
         * local file
         * local directory
-        * Google Storage object
-        * Google Storage URL representing a *.mt or *.ht Hail data,
+        * cloud object
+        * cloud URL representing a *.mt or *.ht Hail data,
           in which case it will check for the existence of a
           *.mt/_SUCCESS or *.ht/_SUCCESS file.
-    :param path: path to the file/directory/object/mt/ht
-    :return: True if the object exists
+    @param path: path to the file/directory/object/mt/ht
+    @param verbose: print on each check
+    @return: True if the object exists
     """
-    if path.startswith('gs://'):
-        logger.info(f'Checking {path} existence')
-        bucket = path.replace('gs://', '').split('/')[0]
-        path = path.replace('gs://', '').split('/', maxsplit=1)[1]
-        path = path.rstrip('/')  # ".mt/" -> ".mt"
-        if any(path.endswith(f'.{suf}') for suf in ['mt', 'ht']):
-            path = os.path.join(path, '_SUCCESS')
-        gs = storage.Client()
-        return gs.get_bucket(bucket).get_blob(path)
-    return os.path.exists(path)
+    if not path:
+        return False
+
+    path = cast(Path, to_path(path))
+
+    # rstrip to ".mt/" -> ".mt"
+    if any(str(path).rstrip('/').endswith(f'.{suf}') for suf in ['mt', 'ht']):
+        path = path / '_SUCCESS'
+
+    if verbose:
+        # noinspection PyBroadException
+        try:
+            res = path.exists()
+        except BaseException:
+            traceback.print_exc()
+            logger.error(f'Failed checking {path}')
+            sys.exit(1)
+        logger.debug(f'Checked {path} [' + ('exists' if res else 'missing') + ']')
+        return res
+    return path.exists()
 
 
 def can_reuse(
-    fpath: Optional[Union[Iterable[str], str]],
+    path: Union[List[Path], Path, str, None],
     overwrite: bool,
-    silent=False,
 ) -> bool:
     """
     Checks if `fpath` is good to reuse in the analysis: it exists
@@ -230,47 +250,20 @@ def can_reuse(
     """
     if overwrite:
         return False
-        
-    if not fpath:
+
+    if not path:
         return False
 
-    if not isinstance(fpath, str):
-        return all(can_reuse(fp, overwrite) for fp in fpath)
+    if isinstance(path, list):
+        return all(can_reuse(fp, overwrite) for fp in path)
 
-    if not file_exists(fpath):
+    if not file_exists(path):
         return False
 
-    if not silent:
-        logger.info(f'Reusing existing {fpath}. Use --overwrite to overwrite')
+    logger.debug(f'Reusing existing {path}. Use --overwrite to overwrite')
     return True
 
 
-def gs_cache_file(fpath: str, local_tmp_dir: str) -> str:
-    """
-    :param fpath: local or a `gs://` path. If the latter, the file
-        will be downloaded and cached if local_tmp_dir is provided,
-        the local path will be returned
-    :param local_tmp_dir: a local directory to cache files downloaded
-        from Google Storage
-    :return: file path
-    """
-    if fpath.startswith('gs://'):
-        fname = (
-            os.path.basename(fpath) + '_' + hashlib.md5(fpath.encode()).hexdigest()[:6]
-        )
-        local_fpath = os.path.join(local_tmp_dir, fname)
-        if not exists(local_fpath):
-            bucket = fpath.replace('gs://', '').split('/')[0]
-            path = fpath.replace('gs://', '').split('/', maxsplit=1)[1]
-            gs = storage.Client()
-            blob = gs.get_bucket(bucket).get_blob(path)
-            if blob:
-                blob.download_to_filename(local_fpath)
-    else:
-        local_fpath = fpath
-    return local_fpath
-
-
 def safe_mkdir(dirpath: str, descriptive_name: str = '') -> str:
     """
     Multiprocessing-safely and recursively creates a directory
@@ -289,7 +282,7 @@ def safe_mkdir(dirpath: str, descriptive_name: str = '') -> str:
     num_tries = 0
     max_tries = 10
 
-    while not exists(dirpath):
+    while not file_exists(to_path(dirpath)):
         # we could get an error here if multiple processes are creating
         # the directory at the same time. Grr, concurrency.
         try:
@@ -409,7 +402,7 @@ def get_filter_cutoffs(
     :return: a Dict with cutoffs
     """
     if provided_filter_cutoffs_path:
-        assert file_exists(provided_filter_cutoffs_path), provided_filter_cutoffs_path
+        assert file_exists(to_path(provided_filter_cutoffs_path)), provided_filter_cutoffs_path
         path = provided_filter_cutoffs_path
     else:
         path = join(get_package_path(), 'filter_cutoffs.yaml')
@@ -529,8 +522,8 @@ float_vals = {
     'r_aligned_in_pairs': None,
 }
 int_vals = {
-    'median_insert_size': None,
-    'median_coverage': None,
+    'insert_size': None,
+    'coverage': None,
 }
 default_entry.update(float_vals)
 default_entry.update(int_vals)
